@@ -25,6 +25,8 @@ for dir in \
   [ -d "$dir" ] || continue
   sudo rm -f -v "$dir/images_yaru.zip"
   sudo rm -f -v "$dir/images_yaru_svg.zip"
+  sudo rm -f -v "$dir/images_yaru_mate.zip"
+  sudo rm -f -v "$dir/images_yaru_mate_svg.zip"
 done
 
 echo -e "\n=> 🎉 Finish\n"
